@@ -173,7 +173,7 @@ class Thing:
         Get the type(s) of the thing.
         Returns the list of types.
         """
-        return list(self._type)
+        return self.type
 
     async def get_description(self):
         """
